@@ -28,11 +28,11 @@
 #include <kapplication.h>
 #include <kwebpage.h>
 #include <kurl.h>
-#include <QDebug>
+#include <kdebug.h>
 
 extern "C"
 {
-    Q_DECL_EXPORT ThumbCreator *new_creator()
+    KDE_EXPORT ThumbCreator *new_creator()
     {
         return new HTMLCreator;
     }
