@@ -55,7 +55,7 @@ using namespace Nepomuk2;
 using namespace Soprano::Vocabulary;
 
 TagsProtocol::TagsProtocol(const QByteArray& pool_socket, const QByteArray& app_socket)
-    : KIO::ForwardingSlaveBase("tags", pool_socket, app_socket)
+    : KIO::ForwardingSlaveBase("nepomuktags", pool_socket, app_socket)
 {
 }
 
@@ -556,7 +556,7 @@ extern "C"
     KDE_EXPORT int kdemain( int argc, char **argv )
     {
         // necessary to use other kio slaves
-        KComponentData( "kio_tags" );
+        KComponentData( "kio_nepomuktags" );
         QCoreApplication app( argc, argv );
 
         if (argc != 4) {
