@@ -41,12 +41,12 @@ class SortFilterModel : public QSortFilterProxyModel
     /**
      * The source model of this sorting proxy model. It has to inherit QAbstractItemModel (ListModel is not supported)
      */
-    Q_PROPERTY(QObject *sourceModel READ sourceModel WRITE setModel)
+    Q_PROPERTY(QAbstractItemModel *sourceModel READ sourceModel WRITE setModel NOTIFY sourceModelChanged)
 
     /**
      * The regular expression for the filter, only items with their filterRole matching filterRegExp will be displayed
      */
-    Q_PROPERTY(QString filterRegExp READ filterRegExp WRITE setFilterRegExp)
+    Q_PROPERTY(QString filterRegExp READ filterRegExp WRITE setFilterRegExp NOTIFY filterRegExpChanged)
 
     /**
      * The role of the sourceModel on which filterRegExp must be applied.
@@ -61,7 +61,12 @@ class SortFilterModel : public QSortFilterProxyModel
     /**
      * One of Qt.Ascending or Qt.Descending
      */
-    Q_PROPERTY(Qt::SortOrder sortOrder READ sortOrder WRITE setSortOrder)
+    Q_PROPERTY(Qt::SortOrder sortOrder READ sortOrder WRITE setSortOrder NOTIFY sortOrderChanged)
+
+    /**
+     * One of Qt.CaseInsensitive or Qt.CaseSensitive
+     */
+    Q_PROPERTY(Qt::CaseSensitivity sortCaseSensitivity READ sortCaseSensitivity WRITE setSortCaseSensitivity)
 
     /**
      * How many items are in this model
@@ -74,8 +79,7 @@ public:
     SortFilterModel(QObject* parent=0);
     ~SortFilterModel();
 
-    //FIXME: find a way to make QML understnd QAbstractItemModel
-    void setModel(QObject *source);
+    void setModel(QAbstractItemModel *source);
 
     void setFilterRegExp(const QString &exp);
     QString filterRegExp() const;
@@ -105,6 +109,9 @@ public:
 
 Q_SIGNALS:
     void countChanged();
+    void sourceModelChanged(QObject *);
+    void filterRegExpChanged(const QString &);
+    void sortOrderChanged(const Qt::SortOrder);
 
 protected:
     int roleNameToId(const QString &name);
@@ -191,6 +198,8 @@ protected:
 
 Q_SIGNALS:
     void countChanged();
+    void sourceModelChanged(QObject *);
+    void filterRegExpChanged(const QString &);
 
 private Q_SLOTS:
     void dataUpdated(const QString &sourceName, const Plasma::DataEngine::Data &data);
